@@ -52,10 +52,10 @@ namespace Oxygen
         protected Q_SLOTS:
 
         //! initialize animation
-        virtual bool initializeAnimation( void );
+        bool initializeAnimation( void ) ;
 
         //! animate
-        virtual bool animate( void );
+        bool animate( void ) ;
 
         //! finish animation
         virtual void finishAnimation( void );
