@@ -28,7 +28,7 @@
 #include "oxygeninactiveshadowconfiguration.h"
 #include "ui_oxygenshadowconfigurationui.h"
 
-#include "oxygenutil.h"
+#include "config-liboxygen.h"
 
 #include <KLocalizedString>
 #include <QLabel>
@@ -63,7 +63,7 @@ namespace Oxygen
     { delete ui; }
 
     //_________________________________________________________
-    void ShadowConfigWidget::writeConfig( KConfig* config ) const
+    void ShadowConfigWidget::save( void ) const
     {
 
         if( _group == QPalette::Active )
@@ -76,7 +76,11 @@ namespace Oxygen
             ActiveShadowConfiguration::setUseOuterColor( ui->useOuterColor->isChecked() );
 
             ActiveShadowConfiguration::setEnabled( isChecked() );
-            Util::writeConfig( ActiveShadowConfiguration::self(), config );
+            #if OXYGEN_USE_KDE4
+            ActiveShadowConfiguration::self()->writeConfig();
+            #else
+            ActiveShadowConfiguration::self()->save();
+            #endif
 
         } else if( _group == QPalette::Inactive ) {
 
@@ -87,7 +91,11 @@ namespace Oxygen
             InactiveShadowConfiguration::setUseOuterColor( ui->useOuterColor->isChecked() );
 
             InactiveShadowConfiguration::setEnabled( isChecked() );
-            Util::writeConfig( InactiveShadowConfiguration::self(), config );
+            #if OXYGEN_USE_KDE4
+            InactiveShadowConfiguration::self()->writeConfig();
+            #else
+            InactiveShadowConfiguration::self()->save();
+            #endif
 
         }
 
@@ -122,13 +130,21 @@ namespace Oxygen
     }
 
     //_________________________________________________________
-    void ShadowConfigWidget::readConfig( KConfig* config, bool defaults )
+    void ShadowConfigWidget::load( bool defaults )
     {
         if( _group == QPalette::Active )
         {
 
             if( defaults ) ActiveShadowConfiguration::self()->setDefaults();
-            else Util::readConfig( ActiveShadowConfiguration::self(), config );
+            else {
+
+                #if OXYGEN_USE_KDE4
+                ActiveShadowConfiguration::self()->readConfig();
+                #else
+                ActiveShadowConfiguration::self()->load();
+                #endif
+
+            }
 
             ui->shadowSize->setValue( ActiveShadowConfiguration::shadowSize() );
             ui->verticalOffset->setValue( 10*ActiveShadowConfiguration::verticalOffset() );
@@ -141,7 +157,15 @@ namespace Oxygen
         } else if( _group == QPalette::Inactive ) {
 
             if( defaults ) InactiveShadowConfiguration::self()->setDefaults();
-            else Util::readConfig( InactiveShadowConfiguration::self(), config );
+            else {
+
+                #if OXYGEN_USE_KDE4
+                InactiveShadowConfiguration::self()->readConfig();
+                #else
+                InactiveShadowConfiguration::self()->load();
+                #endif
+
+            }
 
             ui->shadowSize->setValue( InactiveShadowConfiguration::shadowSize() );
             ui->verticalOffset->setValue( 10*InactiveShadowConfiguration::verticalOffset() );
